==> haskell-pipes-http-1.0.6-758-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-59YmCaohUgkbypKIaNRfJ
key:                  pipes-http-1.0.6-59YmCaohUgkbypKIaNRfJ
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  a17ab47064e77fda5ec91dbdc078abdf
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-59YmCaohUgkbypKIaNRfJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-4oci2LEK5YS94AFA5EFYnF
    http-client-tls-0.3.6.4-C9vh29ljq9FHtoEMbpBYyb
    pipes-4.3.16-CWjFwBVcKQ0Lk4J7E7HAO5

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-759-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-GamN7jaNyCgF72WCPHndHb
key:                  pipes-http-1.0.6-GamN7jaNyCgF72WCPHndHb
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  fce2cee54c01ecb4f0e4f2baee2ad221
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-GamN7jaNyCgF72WCPHndHb
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-3gG1vVFkVnQK6P9M9ZTkXM
    http-client-tls-0.3.6.4-9XDlH6cw2Z89HV4HLa1SKi
    pipes-4.3.16-KhFbCp2e3I6Bs0JkNmuFo6

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
